@@ -80,7 +80,7 @@ class Annotation:
     # The following underscored attributes are just for initialization
     # in case the skeleton is not given. They are always None as attributes.
     _dataset_name: Optional[str] = None
-    _scale: Optional[Vector3] = None
+    _voxel_size: Optional[Vector3] = None
     _organization_id: Optional[str] = None
     _description: Optional[str] = None
     username: Optional[str] = None
@@ -98,8 +98,8 @@ class Annotation:
     def _set_init_docstring(cls) -> None:
         Annotation.__init__.__doc__ = """
         To initialize a local annotation, please provide the `name` argument, and either
-        the `skeleton` argument, or a `dataset_name` and `scale`.
-        When supplying `skeleton` passing `dataset_name`, `scale`, `organization_id` or
+        the `skeleton` argument, or a `dataset_name` and `voxel_size`.
+        When supplying `skeleton` passing `dataset_name`, `voxel_size`, `organization_id` or
         `description` is not allowed as the attributes of the skeleton are used in this case.
         """
 
@@ -108,15 +108,17 @@ class Annotation:
             assert (
                 self._dataset_name is not None
             ), "Please either supply a skeleton or dataset_name for Annotation()."
-            assert self._scale is not None, "Please supply a scale for Annotation()."
+            assert (
+                self._voxel_size is not None
+            ), "Please supply a voxel_size for Annotation()."
             self.skeleton = Skeleton(
                 dataset_name=self._dataset_name,
-                scale=self._scale,
+                voxel_size=self._voxel_size,
                 organization_id=self._organization_id,
                 description=self._description,
             )
             self._dataset_name = None
-            self._scale = None
+            self._voxel_size = None
             self._organization_id = None
             self._description = None
         else:
@@ -124,12 +126,12 @@ class Annotation:
                 i is None
                 for i in [
                     self._dataset_name,
-                    self._scale,
+                    self._voxel_size,
                     self._organization_id,
                     self._description,
                 ]
             ), (
-                "When supplying a skeleton for Annotation(), passing dataset_name, scale, organization_id or description is not allowed. "
+                "When supplying a skeleton for Annotation(), passing dataset_name, voxel_size, organization_id or description is not allowed. "
                 + "The attributes of the skeleton are used in this case."
             )
 
@@ -142,14 +144,26 @@ class Annotation:
     def dataset_name(self, dataset_name: str) -> None:
         self.skeleton.dataset_name = dataset_name
 
+    @property
+    def voxel_size(self) -> Tuple[float, float, float]:
+        """This attribute is a proxy for `skeleton.voxel_size`."""
+        return self.skeleton.voxel_size
+
+    @voxel_size.setter
+    def voxel_size(self, voxel_size: Tuple[float, float, float]) -> None:
+        self.skeleton.voxel_size = voxel_size
+
     @property
     def scale(self) -> Tuple[float, float, float]:
-        """This attribute is a proxy for `skeleton.scale`."""
-        return self.skeleton.scale
+        """Deprecated, please use `voxel_size`."""
+        warn_deprecated("scale", "voxel_size")
+        return self.voxel_size
 
     @scale.setter
     def scale(self, scale: Tuple[float, float, float]) -> None:
-        self.skeleton.scale = scale
+        """Deprecated, please use `voxel_size`."""
+        warn_deprecated("scale", "voxel_size")
+        self.voxel_size = scale
 
     @property
     def organization_id(self) -> Optional[str]:
@@ -204,7 +218,7 @@ class Annotation:
         """
         * `annotation_id_or_url` may be an annotation id or a full URL to an annotation, e.g.
           `https://webknossos.org/annotations/Explorational/6114d9410100009f0096c640`
-        * `annotation_type` must be supplied iff an annotation id was used in the previous argument
+        * `annotation_type` must be supplied if and only if an annotation id was used in the previous argument
         * `webknossos_url` may be supplied if an annotation id was used
           and allows to specifiy in which webknossos instance to search for the annotation.
           It defaults to the url from your current `webknossos_context`, using https://webknossos.org as a fallback.
@@ -236,7 +250,7 @@ class Annotation:
         annotation_type = AnnotationType(annotation_type)
         assert (
             annotation_type not in _COMPOUND_ANNOTATION_TYPES
-        ), f"Currently compund annotation types are not supported, got {annotation_type}"
+        ), f"Currently compound annotation types are not supported, got {annotation_type}"
 
         if webknossos_url is not None and webknossos_url != _get_context().url:
             warnings.warn(
@@ -570,7 +584,7 @@ class Annotation:
                 layer_name, category="segmentation", largest_segment_id=0
             ),
         )
-        best_mag_view = layer.get_best_mag()
+        best_mag_view = layer.get_finest_mag()
 
         if largest_segment_id is None:
             max_value = max(
@@ -601,7 +615,7 @@ class Annotation:
             input_annotation_dataset = Dataset(
                 tmp_annotation_dir,
                 name="tmp_annotation_dataset",
-                scale=self.scale,
+                voxel_size=self.voxel_size,
                 exist_ok=True,
             )
 
