@@ -8,8 +8,10 @@ from rich.progress import track
 
 from webknossos.client._generated.api.datastore import dataset_download
 from webknossos.client._generated.api.default import dataset_info
-from webknossos.client.context import _get_context, _get_generated_client
+from webknossos.client._generated.types import Unset
+from webknossos.client.context import _get_context
 from webknossos.dataset import Dataset, LayerCategoryType
+from webknossos.dataset.properties import LayerViewConfiguration, dataset_converter
 from webknossos.geometry import BoundingBox, Mag, Vec3Int
 
 logger = logging.getLogger(__name__)
@@ -23,7 +25,7 @@ _DOWNLOAD_CHUNK_SIZE = Vec3Int(512, 512, 512)
 
 def download_dataset(
     dataset_name: str,
-    organization_id: Optional[str] = None,
+    organization_id: str,
     sharing_token: Optional[str] = None,
     bbox: Optional[BoundingBox] = None,
     layers: Optional[List[str]] = None,
@@ -31,21 +33,14 @@ def download_dataset(
     path: Optional[Union[PathLike, str]] = None,
     exist_ok: bool = False,
 ) -> Dataset:
-    client = _get_generated_client()
     context = _get_context()
-
-    if organization_id is None:
-        organization_id = context.organization_id
-
-    if sharing_token is None:
-        dataset_name_with_sharing_token = dataset_name
-    else:
-        dataset_name_with_sharing_token = f"{dataset_name}?sharingToken={sharing_token}"
+    client = context.generated_client
 
     dataset_info_response = dataset_info.sync_detailed(
         organization_name=organization_id,
-        data_set_name=dataset_name_with_sharing_token,
+        data_set_name=dataset_name,
         client=client,
+        sharing_token=sharing_token,
     )
     assert dataset_info_response.status_code == 200, dataset_info_response
     parsed = dataset_info_response.parsed
@@ -59,9 +54,11 @@ def download_dataset(
         logger.warning(f"{actual_path} already exists, skipping download.")
         return Dataset.open(actual_path)
 
-    scale = cast(Tuple[float, float, float], tuple(parsed.data_source.scale))
+    voxel_size = cast(Tuple[float, float, float], tuple(parsed.data_source.scale))
     data_layers = parsed.data_source.data_layers
-    dataset = Dataset(actual_path, name=parsed.name, scale=scale, exist_ok=exist_ok)
+    dataset = Dataset(
+        actual_path, name=parsed.name, voxel_size=voxel_size, exist_ok=exist_ok
+    )
     for layer_name in layers or [i.name for i in data_layers]:
 
         response_layers = [i for i in data_layers if i.name == layer_name]
@@ -82,6 +79,19 @@ def download_dataset(
                 "largestSegmentId", None
             ),
         )
+
+        default_view_configuration_dict = None
+        if not isinstance(response_layer.default_view_configuration, Unset):
+            default_view_configuration_dict = (
+                response_layer.default_view_configuration.to_dict()
+            )
+
+        if default_view_configuration_dict is not None:
+            default_view_configuration = dataset_converter.structure(
+                default_view_configuration_dict, LayerViewConfiguration
+            )
+            layer.default_view_configuration = default_view_configuration
+
         if bbox is None:
             response_bbox = response_layer.bounding_box
             layer.bounding_box = BoundingBox(
