@@ -1,7 +1,9 @@
-from typing import Any, Dict, List, Type, TypeVar
+from typing import Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
+from ..types import UNSET, Unset
+
 T = TypeVar("T", bound="UserListResponse200ItemExperiences")
 
 
@@ -9,20 +11,28 @@ T = TypeVar("T", bound="UserListResponse200ItemExperiences")
 class UserListResponse200ItemExperiences:
     """ """
 
+    abc: Union[Unset, int] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        abc = self.abc
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
+        if abc is not UNSET:
+            field_dict["abc"] = abc
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
-        user_list_response_200_item_experiences = cls()
+        abc = d.pop("abc", UNSET)
+
+        user_list_response_200_item_experiences = cls(
+            abc=abc,
+        )
 
         user_list_response_200_item_experiences.additional_properties = d
         return user_list_response_200_item_experiences
