@@ -9,12 +9,13 @@ from pathlib import Path
 from typing import TYPE_CHECKING, Dict, List, Optional, Tuple, Union
 
 import numpy as np
+from upath import UPath
 
+from webknossos.dataset.sampling_modes import SamplingModes
 from webknossos.geometry import BoundingBox, Mag, Vec3Int, Vec3IntLike
 
 from ._array import ArrayException, BaseArray, DataFormat
-from .downsampling_utils import (
-    SamplingModes,
+from ._downsampling_utils import (
     calculate_default_max_mag,
     calculate_mags_to_downsample,
     calculate_mags_to_upsample,
@@ -22,6 +23,7 @@ from .downsampling_utils import (
     downsample_cube_job,
     parse_interpolation_mode,
 )
+from ._upsampling_utils import upsample_cube_job
 from .layer_categories import COLOR_CATEGORY, SEGMENTATION_CATEGORY, LayerCategoryType
 from .properties import (
     LayerProperties,
@@ -31,7 +33,6 @@ from .properties import (
     _properties_floating_type_to_python_type,
     _python_floating_type_to_properties_type,
 )
-from .upsampling_utils import upsample_cube_job
 
 if TYPE_CHECKING:
     from .dataset import Dataset
@@ -40,7 +41,6 @@ from ..utils import (
     copytree,
     get_executor_for_args,
     is_fs_path,
-    make_upath,
     named_partial,
     rmtree,
     warn_deprecated,
@@ -168,12 +168,12 @@ def _get_sharding_parameters(
 
 class Layer:
     """
-    A `Layer` consists of multiple `webknossos.dataset.mag_view.MagView`s, which store the same data in different magnifications.
+    A `Layer` consists of multiple `MagView`s, which store the same data in different magnifications.
     """
 
     def __init__(self, dataset: "Dataset", properties: LayerProperties) -> None:
         """
-        Do not use this constructor manually. Instead use `webknossos.dataset.layer.Dataset.add_layer` to create a `Layer`.
+        Do not use this constructor manually. Instead use `Dataset``.add_layer()` to create a `Layer`.
         """
         # It is possible that the properties on disk do not contain the number of channels.
         # Therefore, the parameter is optional. However at this point, 'num_channels' was already inferred.
@@ -222,6 +222,7 @@ class Layer:
         """
         if layer_name == self.name:
             return
+        self.dataset._ensure_writable()
         assert (
             layer_name not in self.dataset.layers.keys()
         ), f"Failed to rename layer {self.name} to {layer_name}: The new name already exists."
@@ -245,6 +246,36 @@ class Layer:
     def dataset(self) -> "Dataset":
         return self._dataset
 
+    @property
+    def bounding_box(self) -> BoundingBox:
+        return self._properties.bounding_box
+
+    @bounding_box.setter
+    def bounding_box(self, bbox: BoundingBox) -> None:
+        """
+        Updates the offset and size of the bounding box of this layer in the properties.
+        """
+        self.dataset._ensure_writable()
+        assert (
+            bbox.topleft.is_positive()
+        ), f"Updating the bounding box of layer {self} to {bbox} failed, topleft must not contain negative dimensions."
+        self._properties.bounding_box = bbox
+        self.dataset._export_as_json()
+        for mag in self.mags.values():
+            mag._array.ensure_size(
+                bbox.align_with_mag(mag.mag).in_mag(mag.mag).bottomright
+            )
+
+    @property
+    def category(self) -> LayerCategoryType:
+        return COLOR_CATEGORY
+
+    @property
+    def dtype_per_layer(self) -> str:
+        return _dtype_per_channel_to_dtype_per_layer(
+            self.dtype_per_channel, self.num_channels
+        )
+
     @property
     def dtype_per_channel(self) -> np.dtype:
         return self._dtype_per_channel
@@ -267,9 +298,14 @@ class Layer:
     def default_view_configuration(
         self, view_configuration: LayerViewConfiguration
     ) -> None:
+        self.dataset._ensure_writable()
         self._properties.default_view_configuration = view_configuration
         self.dataset._export_as_json()  # update properties on disk
 
+    @property
+    def read_only(self) -> bool:
+        return self.dataset.read_only
+
     @property
     def mags(self) -> Dict[Mag, MagView]:
         """
@@ -290,10 +326,14 @@ class Layer:
             )
         return self.mags[mag]
 
-    def get_best_mag(self) -> MagView:
-
+    def get_finest_mag(self) -> MagView:
         return self.get_mag(min(self.mags.keys()))
 
+    def get_best_mag(self) -> MagView:
+        """Deprecated, please use `get_finest_mag`."""
+        warn_deprecated("get_best_mag()", "get_finest_mag()")
+        return self.get_finest_mag()
+
     def add_mag(
         self,
         mag: Union[int, str, list, tuple, np.ndarray, Mag],
@@ -317,6 +357,7 @@ class Layer:
 
         Raises an IndexError if the specified `mag` already exists.
         """
+        self.dataset._ensure_writable()
         # normalize the name of the mag
         mag = Mag(mag)
         compression_mode = compress
@@ -383,6 +424,7 @@ class Layer:
 
         Raises an IndexError if the specified `mag` does not exists.
         """
+        self.dataset._ensure_writable()
         mag = Mag(mag)
         assert (
             mag not in self.mags
@@ -458,6 +500,7 @@ class Layer:
 
         This function raises an `IndexError` if the specified `mag` does not exist.
         """
+        self.dataset._ensure_writable()
         mag = Mag(mag)
         if mag not in self.mags.keys():
             raise IndexError(
@@ -488,6 +531,7 @@ class Layer:
         by the bounding box of the layer the foreign mag belongs to.
         Symlinked mags can only be added to layers on local file systems.
         """
+        self.dataset._ensure_writable()
 
         if isinstance(foreign_mag_view_or_path, MagView):
             foreign_mag_view = foreign_mag_view_or_path
@@ -495,7 +539,7 @@ class Layer:
             # local import to prevent circular dependency
             from .dataset import Dataset
 
-            foreign_mag_view_path = make_upath(foreign_mag_view_or_path)
+            foreign_mag_view_path = UPath(foreign_mag_view_or_path)
             foreign_mag_view = (
                 Dataset.open(foreign_mag_view_path.parent.parent)
                 .get_layer(foreign_mag_view_path.parent.name)
@@ -590,32 +634,13 @@ class Layer:
                 )
             )
 
-    @property
-    def bounding_box(self) -> BoundingBox:
-        return self._properties.bounding_box
-
-    @bounding_box.setter
-    def bounding_box(self, bbox: BoundingBox) -> None:
-        """
-        Updates the offset and size of the bounding box of this layer in the properties.
-        """
-        assert (
-            bbox.topleft.is_positive()
-        ), f"Updating the bounding box of layer {self} to {bbox} failed, topleft must not contain negative dimensions."
-        self._properties.bounding_box = bbox
-        self.dataset._export_as_json()
-        for mag in self.mags.values():
-            mag._array.ensure_size(
-                bbox.align_with_mag(mag.mag).in_mag(mag.mag).bottomright
-            )
-
     def downsample(
         self,
         from_mag: Optional[Mag] = None,
         max_mag: Optional[Mag] = None,
         interpolation_mode: str = "default",
         compress: bool = True,
-        sampling_mode: str = SamplingModes.ANISOTROPIC,
+        sampling_mode: Union[str, SamplingModes] = SamplingModes.ANISOTROPIC,
         buffer_shape: Optional[Vec3Int] = None,
         force_sampling_scheme: bool = False,
         args: Optional[Namespace] = None,
@@ -625,7 +650,7 @@ class Layer:
         """
         Downsamples the data starting from `from_mag` until a magnification is `>= max(max_mag)`.
         There are three different `sampling_modes`:
-        - 'anisotropic' - The next magnification is chosen so that the width, height and depth of a downsampled voxel assimilate. For example, if the z resolution is worse than the x/y resolution, z won't be downsampled in the first downsampling step(s). As a basis for this method, the scale from the datasource-properties.json is used.
+        - 'anisotropic' - The next magnification is chosen so that the width, height and depth of a downsampled voxel assimilate. For example, if the z resolution is worse than the x/y resolution, z won't be downsampled in the first downsampling step(s). As a basis for this method, the voxel_size from the datasource-properties.json is used.
         - 'isotropic' - Each dimension is downsampled equally.
         - 'constant_z' - The x and y dimensions are downsampled equally, but the z dimension remains the same.
 
@@ -633,7 +658,7 @@ class Layer:
 
         Example:
         ```python
-        from webknossos.dataset.downsampling_utils import SamplingModes
+        from webknossos import SamplingModes
 
         # ...
         # let 'layer' be a `Layer` with only `Mag(1)`
@@ -661,6 +686,8 @@ class Layer:
         if max_mag is None:
             max_mag = calculate_default_max_mag(self.bounding_box.size)
 
+        sampling_mode = SamplingModes.parse(sampling_mode)
+
         if self._properties.bounding_box.size.z == 1:
             if sampling_mode != SamplingModes.CONSTANT_Z:
                 warnings.warn(
@@ -668,22 +695,22 @@ class Layer:
                 )
                 sampling_mode = SamplingModes.CONSTANT_Z
 
-        scale: Optional[Tuple[float, float, float]] = None
-        if sampling_mode == SamplingModes.ANISOTROPIC or sampling_mode == "auto":
-            scale = self.dataset.scale
+        voxel_size: Optional[Tuple[float, float, float]] = None
+        if sampling_mode == SamplingModes.ANISOTROPIC:
+            voxel_size = self.dataset.voxel_size
         elif sampling_mode == SamplingModes.ISOTROPIC:
-            scale = None
+            voxel_size = None
         elif sampling_mode == SamplingModes.CONSTANT_Z:
             max_mag_with_fixed_z = max_mag.to_list()
             max_mag_with_fixed_z[2] = from_mag.to_list()[2]
             max_mag = Mag(max_mag_with_fixed_z)
-            scale = None
+            voxel_size = None
         else:
             raise AttributeError(
                 f"Downsampling failed: {sampling_mode} is not a valid SamplingMode ({SamplingModes.ANISOTROPIC}, {SamplingModes.ISOTROPIC}, {SamplingModes.CONSTANT_Z})"
             )
 
-        mags_to_downsample = calculate_mags_to_downsample(from_mag, max_mag, scale)
+        mags_to_downsample = calculate_mags_to_downsample(from_mag, max_mag, voxel_size)
 
         if len(set([max(m.to_list()) for m in mags_to_downsample])) != len(
             mags_to_downsample
@@ -878,37 +905,47 @@ class Layer:
     def upsample(
         self,
         from_mag: Mag,
-        min_mag: Optional[Mag],
-        compress: bool,
-        sampling_mode: str = SamplingModes.ANISOTROPIC,
+        finest_mag: Mag = Mag(1),
+        compress: bool = False,
+        sampling_mode: Union[str, SamplingModes] = SamplingModes.ANISOTROPIC,
         buffer_shape: Optional[Vec3Int] = None,
         buffer_edge_len: Optional[int] = None,
         args: Optional[Namespace] = None,
+        *,
+        min_mag: Optional[Mag] = None,
     ) -> None:
         """
-        Upsamples the data starting from `from_mag` as long as the magnification is `>= min_mag`.
+        Upsamples the data starting from `from_mag` as long as the magnification is `>= finest_mag`.
         There are three different `sampling_modes`:
-        - 'anisotropic' - The next magnification is chosen so that the width, height and depth of a downsampled voxel assimilate. For example, if the z resolution is worse than the x/y resolution, z won't be downsampled in the first downsampling step(s). As a basis for this method, the scale from the datasource-properties.json is used.
+        - 'anisotropic' - The next magnification is chosen so that the width, height and depth of a downsampled voxel assimilate. For example, if the z resolution is worse than the x/y resolution, z won't be downsampled in the first downsampling step(s). As a basis for this method, the voxel_size from the datasource-properties.json is used.
         - 'isotropic' - Each dimension is downsampled equally.
         - 'constant_z' - The x and y dimensions are downsampled equally, but the z dimension remains the same.
+
+        `min_mag` is deprecated, please use `finest_mag` instead.
         """
         assert (
             from_mag in self.mags.keys()
-        ), f"Failed to downsample data. The from_mag ({from_mag.to_layer_name()}) does not exist."
+        ), f"Failed to upsample data. The from_mag ({from_mag.to_layer_name()}) does not exist."
 
-        if min_mag is None:
-            min_mag = Mag(1)
+        if min_mag is not None:
+            warn_deprecated("upsample(min_mag=…)", "upsample(finest_mag=…)")
+            assert finest_mag == Mag(
+                1
+            ), "Cannot set both min_mag and finest_mag, please only use finest_mag."
+            finest_mag = min_mag
 
-        scale: Optional[Tuple[float, float, float]] = None
-        if sampling_mode == SamplingModes.ANISOTROPIC or sampling_mode == "auto":
-            scale = self.dataset.scale
+        sampling_mode = SamplingModes.parse(sampling_mode)
+
+        voxel_size: Optional[Tuple[float, float, float]] = None
+        if sampling_mode == SamplingModes.ANISOTROPIC:
+            voxel_size = self.dataset.voxel_size
         elif sampling_mode == SamplingModes.ISOTROPIC:
-            scale = None
+            voxel_size = None
         elif sampling_mode == SamplingModes.CONSTANT_Z:
-            min_mag_with_fixed_z = min_mag.to_list()
-            min_mag_with_fixed_z[2] = from_mag.to_list()[2]
-            min_mag = Mag(min_mag_with_fixed_z)
-            scale = self.dataset.scale
+            finest_mag_with_fixed_z = finest_mag.to_list()
+            finest_mag_with_fixed_z[2] = from_mag.to_list()[2]
+            finest_mag = Mag(finest_mag_with_fixed_z)
+            voxel_size = None
         else:
             raise AttributeError(
                 f"Upsampling failed: {sampling_mode} is not a valid UpsamplingMode ({SamplingModes.ANISOTROPIC}, {SamplingModes.ISOTROPIC}, {SamplingModes.CONSTANT_Z})"
@@ -917,7 +954,7 @@ class Layer:
         if buffer_shape is None and buffer_edge_len is not None:
             buffer_shape = Vec3Int.full(buffer_edge_len)
 
-        mags_to_upsample = calculate_mags_to_upsample(from_mag, min_mag, scale)
+        mags_to_upsample = calculate_mags_to_upsample(from_mag, finest_mag, voxel_size)
 
         for prev_mag, target_mag in zip(
             [from_mag] + mags_to_upsample[:-1], mags_to_upsample
@@ -976,6 +1013,7 @@ class Layer:
                 info.chunks_per_shard,
                 info.compression_mode,
             )
+            self._mags[mag]._read_only = self._dataset.read_only
         except ArrayException as e:
             logging.error(
                 f"Failed to setup magnification {mag_name}, which is specified in the datasource-properties.json. See {e}"
@@ -997,16 +1035,6 @@ class Layer:
             % (self.name, self.dtype_per_channel, self.num_channels)
         )
 
-    @property
-    def category(self) -> LayerCategoryType:
-        return COLOR_CATEGORY
-
-    @property
-    def dtype_per_layer(self) -> str:
-        return _dtype_per_channel_to_dtype_per_layer(
-            self.dtype_per_channel, self.num_channels
-        )
-
     def _get_largest_segment_id_maybe(self) -> Optional[int]:
         return None
 
@@ -1021,6 +1049,7 @@ class SegmentationLayer(Layer):
 
     @largest_segment_id.setter
     def largest_segment_id(self, largest_segment_id: int) -> None:
+        self.dataset._ensure_writable()
         if type(largest_segment_id) != int:
             assert largest_segment_id == int(
                 largest_segment_id
