@@ -11,7 +11,6 @@ from concurrent.futures._base import Future
 from datetime import datetime
 from inspect import getframeinfo, stack
 from multiprocessing import cpu_count
-from os import PathLike
 from os.path import relpath
 from pathlib import Path
 from shutil import copyfileobj
@@ -161,6 +160,11 @@ def copy_directory_with_symlinks(
             symlink_path.symlink_to(rel_or_abspath)
 
 
+def setup_warnings() -> None:
+    warnings.filterwarnings("default", category=DeprecationWarning, module="wkcuber")
+    warnings.filterwarnings("default", category=DeprecationWarning, module="webknossos")
+
+
 def setup_logging(args: argparse.Namespace) -> None:
     log_path = Path(f"./logs/cuber_{time.strftime('%Y-%m-%d_%H%M%S')}.txt")
 
@@ -210,37 +214,25 @@ def warn_deprecated(deprecated_item: str, alternative_item: str) -> None:
     warnings.warn(
         f"[DEPRECATION] `{deprecated_item}` is deprecated, please use `{alternative_item}` instead (see {caller.filename}:{caller.lineno})",
         DeprecationWarning,
+        stacklevel=2,
     )
 
 
-def make_upath(maybe_path: Union[str, PathLike, Path]) -> UPath:
-    return maybe_path if isinstance(maybe_path, UPath) else UPath(maybe_path)
-
-
 def is_fs_path(path: Path) -> bool:
-    # Distinguish between `pathlib.*Path` and `UPath` through a `UPath`-specific attribute
-    return not hasattr(path, "_url")
-
-
-def is_symlink(path: Path) -> bool:
-    try:
-        return path.is_symlink()
-    except NotImplementedError:
-        # `Path` raises `NotImplmentedError` for some methods, including `is_symlink`
-        return False
+    return not isinstance(path, UPath)
 
 
 def rmtree(path: Path) -> None:
     def _walk(path: Path) -> Iterator[Path]:
         if path.exists():
-            if path.is_dir() and not is_symlink(path):
+            if path.is_dir() and not path.is_symlink():
                 for p in path.iterdir():
                     yield from _walk(p)
             yield path
 
     for sub_path in _walk(path):
         try:
-            if sub_path.is_file() or is_symlink(sub_path):
+            if sub_path.is_file() or sub_path.is_symlink():
                 sub_path.unlink()
             elif sub_path.is_dir():
                 sub_path.rmdir()
